==> haskell-stringbuilder-0.5.1-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-4feU7s7oERe1J4feJXvSVL
key:                  stringbuilder-0.5.1-4feU7s7oERe1J4feJXvSVL
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  f234c228986154bdde419f3afb99ecb2
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-8.10.1/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/stringbuilder-0.5.1
hs-libraries:         HSstringbuilder-0.5.1-4feU7s7oERe1J4feJXvSVL
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringbuilder-0.5.1-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-HjDjY5i5RHvKRY1lHmDZW
key:                  stringbuilder-0.5.1-HjDjY5i5RHvKRY1lHmDZW
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  ac0d70b829bb5697729dbfd5c561687d
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-8.10.2/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/stringbuilder-0.5.1
hs-libraries:         HSstringbuilder-0.5.1-HjDjY5i5RHvKRY1lHmDZW
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
